==> spip_4.0.4.orig.tar.xz: plugins-dist/mots/lang/mots_fi.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=fi
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Tärkeä ryhmä:</b> On erittäin suositeltavaa, että valitset hakusanan tässä ryhmässä.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'sivuston ylläpitäjät',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'toimittajat',

	// I
	'info_articles_lies_mot' => 'Tähän hakusanaan liittyvät artikkelit',
	'info_changer_nom_groupe' => 'Vaihda tämän ryhmän nimeä:',
	'info_creation_mots_cles' => 'Tästä voit luoda ja muokat sivuston hakusanoja',
	'info_mots_cles' => 'Hakusanoja',
	'info_mots_cles_association' => 'Tämän ryhmän hakusanojen kanssa voidaan yhdistää:',
	'info_oui_suppression_mot_cle' => 'Haluan poistaa hakusanan pysyvästi.',
	'info_question_mots_cles' => 'Haluatko käyttää hakusanoja sivustossasi?',
	'info_qui_attribue_mot_cle' => 'Ryhmän hakusanoja voi määritellä:',
	'info_retirer_mot' => 'Poista tämä hakusana',
	'info_retirer_mots' => 'Poista kaikki hakusanat',
	'info_rubriques_liees_mot' => 'Lohkoja liittyen tähän hakusanaan',
	'info_selection_un_seul_mot_cle' => 'Voit nyt valita <b>ainoastaan yhden hakusanan</b> kerralla tässä ryhmässä.', # MODIF
	'info_supprimer_mot' => 'poista tämä hakusana',
	'info_titre_mot_cle' => 'Tämän hakusanan nimi tai otsikko',
	'item_utiliser_config_groupe_mots_cles' => 'Ota käyttöön laajaat hakusanaryhmät',

	// T
	'texte_nouveau_mot' => 'Uusi hakusana',
	'titre_config_groupe_mots_cles' => 'Hakusana-ryhmän asetukset',
	'titre_gauche_mots_edit' => 'HAKUSANA NUMERO:',
	'titre_mots_cles_dans_forum' => 'Julksien sivuston hakusanoja',
	'titre_mots_tous' => 'Hakusanoja',
	'titre_nouveau_groupe' => 'Uusi ryhmä',
	'titre_page_mots_tous' => 'Hakusanoja'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_fi.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=fi
// ** ne pas modifier le fichier **

return [

	// A
	'avis_conseil_selection_mot_cle' => '<b>Tärkeä ryhmä:</b> On erittäin suositeltavaa, että valitset hakusanan tässä ryhmässä.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'sivuston ylläpitäjät',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'toimittajat',

	// I
	'info_articles_lies_mot' => 'Tähän hakusanaan liittyvät artikkelit',
	'info_changer_nom_groupe' => 'Vaihda tämän ryhmän nimeä:',
	'info_creation_mots_cles' => 'Tästä voit luoda ja muokat sivuston hakusanoja',
	'info_mots_cles' => 'Hakusanoja',
	'info_mots_cles_association' => 'Tämän ryhmän hakusanojen kanssa voidaan yhdistää:',
	'info_oui_suppression_mot_cle' => 'Haluan poistaa hakusanan pysyvästi.',
	'info_question_mots_cles' => 'Haluatko käyttää hakusanoja sivustossasi?',
	'info_qui_attribue_mot_cle' => 'Ryhmän hakusanoja voi määritellä:',
	'info_retirer_mot' => 'Poista tämä hakusana',
	'info_retirer_mots' => 'Poista kaikki hakusanat',
	'info_rubriques_liees_mot' => 'Lohkoja liittyen tähän hakusanaan',
	'info_selection_un_seul_mot_cle' => 'Voit nyt valita <b>ainoastaan yhden hakusanan</b> kerralla tässä ryhmässä.', # MODIF
	'info_supprimer_mot' => 'poista tämä hakusana',
	'info_titre_mot_cle' => 'Tämän hakusanan nimi tai otsikko',
	'item_utiliser_config_groupe_mots_cles' => 'Ota käyttöön laajaat hakusanaryhmät',

	// T
	'texte_nouveau_mot' => 'Uusi hakusana',
	'titre_config_groupe_mots_cles' => 'Hakusana-ryhmän asetukset',
	'titre_gauche_mots_edit' => 'HAKUSANA NUMERO:',
	'titre_mots_cles_dans_forum' => 'Julksien sivuston hakusanoja',
	'titre_mots_tous' => 'Hakusanoja',
	'titre_nouveau_groupe' => 'Uusi ryhmä',
	'titre_page_mots_tous' => 'Hakusanoja',
];
